"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports.CScrollLock = void 0;

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _vue = require("vue");

var _bodyScollLock = require("./body-scoll-lock.directive");

/**
 * Hey! Welcome to @chakra-ui/vue-next CScrollLock
 *
 * Component that comes witha hook and directive to enable and disable body scrolling
 *
 * @see Docs     https://next.vue.chakra-ui.com/c-scroll-lock
 * @see Source   https://github.com/chakra-ui/chakra-ui-vue-next/blob/master/packages/c-scroll-lock/src/c-scroll-lock/c-scroll-lock.ts
 * @see WAI-ARIA https://www.w3.org/TR/wai-aria-practices-1.2
 */
var CScrollLock = (0, _vue.defineComponent)({
  name: 'CScrollLock',
  props: {
    enabled: {
      type: Boolean,
      "default": false
    }
  },
  setup: function setup(props, _ref) {
    var slots = _ref.slots,
        attrs = _ref.attrs;
    return function () {
      var _ref2 = slots["default"] == null ? void 0 : slots["default"]({}),
          firstChild = _ref2[0];

      if (!firstChild) {
        console.warn("[chakra-ui:focus-lock]: Focus lock component expects at least and only one child element.");
        return;
      }

      var scrollLockVNode = (0, _vue.cloneVNode)(firstChild, (0, _extends2["default"])({}, attrs, {
        'data-chakra-scroll-lock': "" + props.enabled
      }));
      return (0, _vue.withDirectives)(scrollLockVNode, [[_bodyScollLock.BodyScrollLockDirective, props.enabled]]);
    };
  }
});
exports.CScrollLock = CScrollLock;
//# sourceMappingURL=c-scroll-lock.js.map